@@ -11,19 +11,19 @@ use Try::Tiny;
 #------------------------------------------------------------------------------
 # 定义设备 Connector 通用属性
 #------------------------------------------------------------------------------
-has host => ( is => 'ro', required => 0, );
+has host => (is => 'ro', required => 0,);
 
-has username => ( is => 'ro', required => 0, default => 'read' );
+has username => (is => 'ro', required => 0, default => 'read');
 
-has password => ( is => 'ro', required => 0, default => '', );
+has password => (is => 'ro', required => 0, default => '',);
 
-has enpassword => ( is => 'ro', required => 0, );
+has enpassword => (is => 'ro', required => 0,);
 
-has proto => ( is => 'ro', required => 0, default => 'ssh', );
+has proto => (is => 'ro', required => 0, default => 'ssh',);
 
-has _login_ => ( is => 'ro', required => 0, default => 0, );
+has _login_ => (is => 'ro', required => 0, default => 0,);
 
-has _enable_ => ( is => 'ro', required => 0, default => 0, );
+has _enable_ => (is => 'ro', required => 0, default => 0,);
 
 #------------------------------------------------------------------------------
 # Huawei 设备登陆函数入口
@@ -36,7 +36,7 @@ sub login {
 
   # 尝试连接设备进行响应逻辑判断
   try {
-    $self->connect() unless ( defined $self->{exp} );
+    $self->connect() unless (defined $self->{exp});
   }
   catch {
     if (/RSA modulus too small/mi) {
@@ -84,10 +84,10 @@ sub login {
 # Huawei 设备 Expect 初始化函数入口
 #------------------------------------------------------------------------------
 sub connect {
-  my ( $self, $args ) = @_;
+  my ($self, $args) = @_;
 
   # 检查是否携带变量并初始化
-  $args = "" unless ( defined $args );
+  $args = "" unless (defined $args);
   my $host     = $self->{host};
   my $prompt   = '^\s*\S+[>\]]\s*$';
   my $username = $self->{username};
@@ -108,40 +108,44 @@ sub connect {
   $exp->spawn($command) || die "Cannot spawn $command: $!\n";
   my @ret = $exp->expect(
     45,
-    [ qr/\(yes\/no\)\?\s*$/mi => sub {
+    [
+      qr/\(yes\/no\)\?\s*$/mi => sub {
         $exp->send("yes\n");
         exp_continue;
       }
     ],
-    [ qr/assword:\s*$/mi => sub {
+    [
+      qr/assword:\s*$/mi => sub {
         if ($login_flag) {
           $login_flag = 0;
           $exp->send("$password\n");
         }
         else {
-          croak "username or password is wrong!";
+          confess "username or password is wrong!";
         }
         exp_continue;
       }
     ],
-    [ qr/(ogin|name):\s*$/mi => sub {
+    [
+      qr/(ogin|name):\s*$/mi => sub {
         $exp->send("$username\n");
         exp_continue;
       }
     ],
-    [ qr/$prompt/m => sub {
+    [
+      qr/$prompt/m => sub {
         $self->{_login_} = 1;
       }
     ],
   );
 
   # Expect是否异常
-  if ( defined $ret[1] ) {
-    croak $ret[3] . $ret[1];
+  if (defined $ret[1]) {
+    confess $ret[3] . $ret[1];
   }
 
   # 是否进入 enable 模式
-  if ( $exp->match() =~ /\]\s+\z/ ) {
+  if ($exp->match() =~ /\]\s+\z/) {
     $self->{_enable_} = 1;
   }
 
@@ -152,7 +156,7 @@ sub connect {
 #------------------------------------------------------------------------------
 # Huawei 设备抓取运行配置函数入口
 #------------------------------------------------------------------------------
-sub getconfig {
+sub getConfig {
   my $self = shift;
 
   # 抓取设备命令脚本，输入不分页命令加速输出
@@ -161,7 +165,7 @@ sub getconfig {
   my $lines    = "";
 
   # 判断是否执行成功
-  if ( $config->{success} == 1 ) {
+  if ($config->{success} == 1) {
     $lines = $config->{result};
   }
   else {
@@ -170,13 +174,13 @@ sub getconfig {
 
   # 输出计算结果
   return {success => 1, config => $lines};
-} ## end sub getconfig
+} ## end sub getConfig
 
 #------------------------------------------------------------------------------
 # Huawei 设备发送指令入口函数，接收字符串
 #------------------------------------------------------------------------------
 sub send {
-  my ( $self, $command ) = @_;
+  my ($self, $command) = @_;
   my $exp = $self->{exp};
   $exp->send($command);
 }
@@ -185,7 +189,7 @@ sub send {
 # Huawei 设备捕捉命令输入 prompt 回显
 #------------------------------------------------------------------------------
 sub waitfor {
-  my ( $self, $prompt ) = @_;
+  my ($self, $prompt) = @_;
 
   # 定义需要捕捉的回显字符串
   $prompt = '^.+[>\]]\s*\z' if not defined $prompt;
@@ -193,7 +197,8 @@ sub waitfor {
   my $buff = "";
   my @ret  = $exp->expect(
     15,
-    [ qr/.+more.+$/mi => sub {
+    [
+      qr/.+more.+$/mi => sub {
         $exp->send(" ");
 
         # 捕捉配置分页关键字无需写入buff
@@ -201,39 +206,44 @@ sub waitfor {
         exp_continue;
       }
     ],
-    [ qr/Are\s+you\s+sure\?\s*\[Y\/N\]/mi => sub {
+    [
+      qr/Are\s+you\s+sure\?\s*\[Y\/N\]/mi => sub {
         $buff .= $exp->before() . $exp->match();
         $exp->send("Y\n");
         exp_continue;
       }
     ],
-    [ qr/press the enter key\)/mi => sub {
+    [
+      qr/press the enter key\)/mi => sub {
         $buff .= $exp->before() . $exp->match();
         $exp->send("\n");
         exp_continue;
       }
     ],
-    [ qr/overwrite\?\s*\[Y\/N\]/mi => sub {
+    [
+      qr/overwrite\?\s*\[Y\/N\]/mi => sub {
         $buff .= $exp->before() . $exp->match();
         $exp->send("Y\n");
         exp_continue;
       }
     ],
-    [ qr/^\%.+\z/mi => sub {
+    [
+      qr/^\%.+\z/mi => sub {
         $buff .= $exp->before();
         $exp->send(" ");
         exp_continue;
       }
     ],
-    [ qr/$prompt/m => sub {
+    [
+      qr/$prompt/m => sub {
         $buff .= $exp->before() . $exp->match();
       }
     ]
   );
 
   # 如果捕捉到异常记录，跳出函数
-  if ( defined $ret[1] ) {
-    croak $ret[3] . $ret[1];
+  if (defined $ret[1]) {
+    confess $ret[3] . $ret[1];
   }
 
   # 处理非常态配置，影响计算哈希
@@ -250,16 +260,16 @@ sub waitfor {
 # Huawei 设备 execCommands 函数入口
 #------------------------------------------------------------------------------
 sub execCommands {
-  my ( $self, @commands ) = @_;
+  my ($self, @commands) = @_;
 
   # 判断是否已登陆设备
-  if ( $self->{_login_} == 0 ) {
+  if ($self->{_login_} == 0) {
     my $ret = $self->login();
-    return $ret unless ( $ret->{success} );
+    return $ret unless ($ret->{success});
   }
 
   # 判断是否进入 enable 模式
-  $self->enable() unless ( $self->{_enable_} );
+  $self->enable() unless ($self->{_enable_});
 
   # 初始化 result 变量，并开始执行命令
   my $result = "";
@@ -267,11 +277,11 @@ sub execCommands {
 
     # 跳过空白行
     next if $cmd =~ /^\s*$/;
-    $self->send( $cmd . "\n" );
+    $self->send($cmd . "\n");
     my $buff = $self->waitfor();
 
     # 异常回显信号捕捉
-    if ( $buff =~ /(^\s*\^|error:)/m ) {
+    if ($buff =~ /(^\s*\^|error:)/m) {
       return {success => 0, failCommand => $cmd, reason => $result . $buff};
     }
     else {
@@ -297,28 +307,32 @@ sub enable {
   my $enable_flag = 1;
   my @ret         = $exp->expect(
     15,
-    [ qr/assword:\s*$/mi => sub {
+    [
+      qr/assword:\s*$/mi => sub {
         if ($enable_flag) {
           $enable_flag = 0;
           $exp->send("$enpasswd\n");
         }
         else {
-          croak "username or enpasswd is wrong!";
+          confess "username or enpasswd is wrong!";
         }
         exp_continue;
       }
     ],
-    [ qr/(ogin|name):\s*$/mi => sub {
+    [
+      qr/(ogin|name):\s*$/mi => sub {
         $exp->send("$username\n");
         exp_continue;
       }
     ],
-    [ qr/\(privilege\s+level\s+is.+>\s*\z\)/mi => sub {
+    [
+      qr/\(privilege\s+level\s+is.+>\s*\z\)/mi => sub {
         $self->{_enable_} = 1;
         return 1;
       }
     ],
-    [ qr/\(privilege\s+is\s+.+>\s*\z\)/mi => sub {
+    [
+      qr/\(privilege\s+is\s+.+>\s*\z\)/mi => sub {
         $self->{_enable_} = 1;
         return 1;
       }
@@ -326,8 +340,8 @@ sub enable {
   );
 
   # 异常回显信号捕捉
-  if ( defined $ret[1] ) {
-    croak $ret[3] . $ret[1];
+  if (defined $ret[1]) {
+    confess $ret[3] . $ret[1];
   }
 } ## end sub enable
 
