@@ -11,17 +11,17 @@ use Try::Tiny;
 #------------------------------------------------------------------------------
 # 定义设备 Connector 通用属性
 #------------------------------------------------------------------------------
-has host => ( is => 'ro', required => 0, );
+has host => (is => 'ro', required => 0,);
 
-has username => ( is => 'ro', required => 0, );
+has username => (is => 'ro', required => 0,);
 
-has password => ( is => 'ro', required => 0, );
+has password => (is => 'ro', required => 0,);
 
-has enpassword => ( is => 'ro', required => 0, );
+has enpassword => (is => 'ro', required => 0,);
 
-has proto => ( is => 'ro', required => 0, default => 'ssh', );
+has proto => (is => 'ro', required => 0, default => 'ssh',);
 
-has _login_ => ( is => 'ro', required => 0, default => 0, );
+has _login_ => (is => 'ro', required => 0, default => 0,);
 
 #------------------------------------------------------------------------------
 # Topsec 设备登陆函数入口
@@ -34,7 +34,7 @@ sub login {
 
   # 尝试连接设备进行响应逻辑判断
   try {
-    $self->connect() unless ( defined $self->{exp} );
+    $self->connect() unless (defined $self->{exp});
   }
   catch {
     if (/RSA modulus too small/mi) {
@@ -82,10 +82,10 @@ sub login {
 # Topsec 设备 Expect 初始化函数入口
 #------------------------------------------------------------------------------
 sub connect {
-  my ( $self, $args ) = @_;
+  my ($self, $args) = @_;
 
   # 检查是否携带变量并初始化
-  $args = "" unless ( defined $args );
+  $args = "" unless (defined $args);
   my $host     = $self->{host};
   my $prompt   = '^\S+\s*[#>$%]\s*\z';
   my $username = $self->{username};
@@ -96,7 +96,7 @@ sub connect {
   $self->{exp} = $exp;
 
   # 可能是一个BUG点，没有该功能
-  $exp->slave()->set_winsize( 1000, 1000, 1000, 1000 );
+  $exp->slave()->set_winsize(1000, 1000, 1000, 1000);
   $exp->raw_pty(1);
   $exp->restart_timeout_upon_receive(1);
 
@@ -109,36 +109,40 @@ sub connect {
   $exp->spawn($command) || die "Cannot spawn $command: $!\n";
   my @ret = $exp->expect(
     10,
-    [ qr/\(yes\/no\)\?\s*$/mi => sub {
+    [
+      qr/\(yes\/no\)\?\s*$/mi => sub {
         $exp->send("yes\n");
         exp_continue;
       }
     ],
-    [ qr/assword:\s*$/mi => sub {
+    [
+      qr/assword:\s*$/mi => sub {
         if ($loginFlag) {
           $loginFlag = 0;
           $exp->send("$password\n");
         }
         else {
-          croak "username or password is wrong!";
+          confess "username or password is wrong!";
         }
         exp_continue;
       }
     ],
-    [ qr/ogin:\s*$/mi => sub {
+    [
+      qr/ogin:\s*$/mi => sub {
         $exp->send("$username\n");
         exp_continue;
       }
     ],
-    [ qr/$prompt/ => sub {
+    [
+      qr/$prompt/ => sub {
         $self->{_login_} = 1;
       }
     ],
   );
 
   # Expect是否异常
-  if ( defined $ret[1] ) {
-    croak $ret[3] . $ret[1];
+  if (defined $ret[1]) {
+    confess $ret[3] . $ret[1];
   }
 
   # 输出计算结果
@@ -148,7 +152,7 @@ sub connect {
 #------------------------------------------------------------------------------
 # Topsec 设备抓取运行配置函数入口
 #------------------------------------------------------------------------------
-sub getconfig {
+sub getConfig {
   my $self = shift;
 
   # 抓取设备命令脚本，输入不分页命令加速输出
@@ -157,7 +161,7 @@ sub getconfig {
   my $lines    = "";
 
   # 判断是否执行成功
-  if ( $config->{success} == 1 ) {
+  if ($config->{success} == 1) {
     $lines = $config->{result};
   }
   else {
@@ -166,13 +170,13 @@ sub getconfig {
 
   # 输出计算结果
   return {success => 1, config => $lines};
-} ## end sub getconfig
+} ## end sub getConfig
 
 #------------------------------------------------------------------------------
 # Topsec 设备发送指令入口函数，接收字符串
 #------------------------------------------------------------------------------
 sub send {
-  my ( $self, $command ) = @_;
+  my ($self, $command) = @_;
   my $exp = $self->{exp};
   $exp->send($command);
 }
@@ -181,7 +185,7 @@ sub send {
 # Topsec 设备捕捉命令输入 prompt 回显
 #------------------------------------------------------------------------------
 sub waitfor {
-  my ( $self, $prompt ) = @_;
+  my ($self, $prompt) = @_;
 
   # 定义需要捕捉的回显字符串
   $prompt = '^\S+[$%#]\s*\z' if not defined $prompt;
@@ -189,7 +193,8 @@ sub waitfor {
   my $buff = "";
   my @ret  = $exp->expect(
     30,
-    [ qr/--More--/mi => sub {
+    [
+      qr/--More--/mi => sub {
         $exp->send(" ");
 
         # 捕捉配置分页关键字无需写入buff
@@ -197,15 +202,16 @@ sub waitfor {
         exp_continue;
       }
     ],
-    [ qr/$prompt/m => sub {
+    [
+      qr/$prompt/m => sub {
         $buff .= $exp->before() . $exp->match();
       }
     ]
   );
 
   # 如果捕捉到异常记录，跳出函数
-  if ( defined $ret[1] ) {
-    croak $ret[3] . $ret[1];
+  if (defined $ret[1]) {
+    confess $ret[3] . $ret[1];
   }
 
   # 输出计算结果
@@ -216,10 +222,10 @@ sub waitfor {
 # Topsec 设备 execCommands 函数入口
 #------------------------------------------------------------------------------
 sub execCommands {
-  my ( $self, @commands ) = @_;
+  my ($self, @commands) = @_;
 
   # 判断是否已登陆设备
-  if ( $self->{_login_} == 0 ) {
+  if ($self->{_login_} == 0) {
     my $ret = $self->login();
     return $ret unless $ret->{success};
   }
@@ -230,11 +236,11 @@ sub execCommands {
 
     # 跳过空白行
     next if $cmd =~ /^\s*$/;
-    $self->send( $cmd . "\n" );
+    $self->send($cmd . "\n");
     my $buff = $self->waitfor();
 
     # 异常回显信号捕捉
-    if ( $buff =~ /error\s+-\d+/mi ) {
+    if ($buff =~ /error\s+-\d+/mi) {
       return {success => 0, failCommand => $cmd, reason => $result . $buff};
     }
     else {
